aboutsummaryrefslogtreecommitdiff
path: root/src/rpc/util.h
diff options
context:
space:
mode:
authorMarcoFalke <falke.marco@gmail.com>2019-02-12 20:16:29 -0500
committerMarcoFalke <falke.marco@gmail.com>2019-02-20 13:32:17 -0500
commitfa05626ca7a0fe896ac554c79eaea4c36acdf861 (patch)
tree7aa3908300e4233d608666a05ec48c232432d926 /src/rpc/util.h
parentf9775a865597b3cc926ba3375fa692516c7415be (diff)
downloadbitcoin-fa05626ca7a0fe896ac554c79eaea4c36acdf861.tar.xz
rpc: Add RPCHelpMan::IsValidNumArgs()
Diffstat (limited to 'src/rpc/util.h')
-rw-r--r--src/rpc/util.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/src/rpc/util.h b/src/rpc/util.h
index 1c9ddcdf44..7b8dd5a9ec 100644
--- a/src/rpc/util.h
+++ b/src/rpc/util.h
@@ -1,4 +1,4 @@
-// Copyright (c) 2017-2018 The Bitcoin Core developers
+// Copyright (c) 2017-2019 The Bitcoin Core developers
// Distributed under the MIT software license, see the accompanying
// file COPYING or http://www.opensource.org/licenses/mit-license.php.
@@ -53,7 +53,7 @@ struct RPCArg {
/** Required arg */
NO,
/**
* Optinal arg that is a named argument and has a default value of
* `null`. When possible, the default value should be specified.
*/
OMITTED_NAMED_ARG,
@@ -110,6 +110,8 @@ struct RPCArg {
assert(type == Type::ARR || type == Type::OBJ);
}
+ bool IsOptional() const;
+
/**
* Return the type string of the argument.
* Set oneline to allow it to be overridden by a custom oneline type string (m_oneline_description).
@@ -185,6 +187,8 @@ public:
RPCHelpMan(std::string name, std::string description, std::vector<RPCArg> args, RPCResults results, RPCExamples examples);
std::string ToString() const;
+ /** If the supplied number of args is neither too small nor too high */
+ bool IsValidNumArgs(size_t num_args) const;
private:
const std::string m_name;
@@ -53,7 +53,7 @@ struct RPCArg {
NO,
/**
- * Optinal arg that is a named argument and has a default value of
+ * Optional arg that is a named argument and has a default value of
* `null`. When possible, the default value should be specified.
*/